==> zio-aws-lakeformation_2.13-5.17.207.1-sources.jar: zio/aws/lakeformation/model/UpdateResourceRequest.scala <==
package zio.aws.lakeformation.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.lakeformation.model.primitives.{ResourceArnString, IAMRoleArn}
import scala.jdk.CollectionConverters._
final case class UpdateResourceRequest(
    roleArn: IAMRoleArn,
    resourceArn: ResourceArnString
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lakeformation.model.UpdateResourceRequest = {
    import UpdateResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lakeformation.model.UpdateResourceRequest
      .builder()
      .roleArn(IAMRoleArn.unwrap(roleArn): java.lang.String)
      .resourceArn(ResourceArnString.unwrap(resourceArn): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.lakeformation.model.UpdateResourceRequest.ReadOnly =
    zio.aws.lakeformation.model.UpdateResourceRequest.wrap(buildAwsValue())
}
object UpdateResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lakeformation.model.UpdateResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lakeformation.model.UpdateResourceRequest =
      zio.aws.lakeformation.model.UpdateResourceRequest(roleArn, resourceArn)
    def roleArn: IAMRoleArn
    def resourceArn: ResourceArnString
    def getRoleArn: ZIO[Any, Nothing, IAMRoleArn] = ZIO.succeed(roleArn)
    def getResourceArn: ZIO[Any, Nothing, ResourceArnString] =
      ZIO.succeed(resourceArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lakeformation.model.UpdateResourceRequest
  ) extends zio.aws.lakeformation.model.UpdateResourceRequest.ReadOnly {
    override val roleArn: IAMRoleArn =
      zio.aws.lakeformation.model.primitives.IAMRoleArn(impl.roleArn())
    override val resourceArn: ResourceArnString =
      zio.aws.lakeformation.model.primitives
        .ResourceArnString(impl.resourceArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.lakeformation.model.UpdateResourceRequest
  ): zio.aws.lakeformation.model.UpdateResourceRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-lakeformation_2.13-6.20.78.2-sources.jar: zio/aws/lakeformation/model/UpdateResourceRequest.scala <==
package zio.aws.lakeformation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.lakeformation.model.primitives.{
  NullableBoolean,
  ResourceArnString,
  IAMRoleArn
}
import scala.jdk.CollectionConverters._
final case class UpdateResourceRequest(
    roleArn: IAMRoleArn,
    resourceArn: ResourceArnString,
    withFederation: Optional[NullableBoolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lakeformation.model.UpdateResourceRequest = {
    import UpdateResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lakeformation.model.UpdateResourceRequest
      .builder()
      .roleArn(IAMRoleArn.unwrap(roleArn): java.lang.String)
      .resourceArn(ResourceArnString.unwrap(resourceArn): java.lang.String)
      .optionallyWith(withFederation.map(value => value: java.lang.Boolean))(
        _.withFederation
      )
      .build()
  }
  def asReadOnly: zio.aws.lakeformation.model.UpdateResourceRequest.ReadOnly =
    zio.aws.lakeformation.model.UpdateResourceRequest.wrap(buildAwsValue())
}
object UpdateResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lakeformation.model.UpdateResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lakeformation.model.UpdateResourceRequest =
      zio.aws.lakeformation.model.UpdateResourceRequest(
        roleArn,
        resourceArn,
        withFederation.map(value => value)
      )
    def roleArn: IAMRoleArn
    def resourceArn: ResourceArnString
    def withFederation: Optional[NullableBoolean]
    def getRoleArn: ZIO[Any, Nothing, IAMRoleArn] = ZIO.succeed(roleArn)
    def getResourceArn: ZIO[Any, Nothing, ResourceArnString] =
      ZIO.succeed(resourceArn)
    def getWithFederation: ZIO[Any, AwsError, NullableBoolean] =
      AwsError.unwrapOptionField("withFederation", withFederation)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lakeformation.model.UpdateResourceRequest
  ) extends zio.aws.lakeformation.model.UpdateResourceRequest.ReadOnly {
    override val roleArn: IAMRoleArn =
      zio.aws.lakeformation.model.primitives.IAMRoleArn(impl.roleArn())
    override val resourceArn: ResourceArnString =
      zio.aws.lakeformation.model.primitives
        .ResourceArnString(impl.resourceArn())
    override val withFederation: Optional[NullableBoolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.withFederation())
        .map(value => value: NullableBoolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.lakeformation.model.UpdateResourceRequest
  ): zio.aws.lakeformation.model.UpdateResourceRequest.ReadOnly = new Wrapper(
    impl
  )
}
